@@ -335,15 +335,27 @@ class ChangesProcessor(Object):
         product.brand = brand
 
         family = None
-        if row['F16']:
+        F16 = self.int_(row[u'F16'])
+        if F16:
             family = session.query(model.Family)\
-                .filter(model.Family.code == row['F16'])\
+                .filter(model.Family.code == F16)\
                 .first()
             if not family:
-                family = model.Family(code=row['F16'])
+                family = model.Family(code=F16)
                 session.add(family)
         product.family = family
 
+        report_code = None
+        F18 = self.int_(row[u'F18'])
+        if F18:
+            report_code = session.query(model.ReportCode)\
+                .filter(model.ReportCode.code == F18)\
+                .first()
+            if not report_code:
+                report_code = model.ReportCode(code=F18)
+                session.add(report_code)
+        product.report_code = report_code
+
         return product
 
     def process_obj_del(self, row, session):
