@@ -33,9 +33,11 @@ import csv
 import logging
 from collections import namedtuple
 
+from locsms.db import Session
+from locsms.db import model as locsms
+
 import edbob
 
-import rattail_locsms as locsms
 from rattail import sil
 from rattail.core import Object
 from rattail.files import locking_copy, temp_path, overwriting_move
@@ -122,7 +124,7 @@ def process_transfer(csv_path, node=None):
 
     add_costs = []
     change_costs = []
-    session = locsms.Session()
+    session = Session()
     for upc in upcs:
 
         product = session.query(locsms.Product).get(upc)
